@@ -3,7 +3,7 @@ import shlex
 import asyncio
 from io import BytesIO
 from dataclasses import dataclass
-from asyncio import TimerHandle, Semaphore
+from asyncio import TimerHandle
 from typing import Dict, List, Optional, NoReturn
 
 from nonebot.matcher import Matcher
@@ -64,17 +64,15 @@ class Options:
 
 games: Dict[str, Wordle] = {}
 timers: Dict[str, TimerHandle] = {}
-mutex = Semaphore(1)
 
 wordle = on_shell_command("wordle", parser=parser, block=True, priority=13)
 
 
 @wordle.handle()
 async def _(
-    matcher: Matcher, event: GroupMessageEvent, argv: List[str] = ShellCommandArgv()
+    matcher: Matcher, event: MessageEvent, argv: List[str] = ShellCommandArgv()
 ):
-    async with mutex:
-        await handle_wordle(matcher, event, argv)
+    await handle_wordle(matcher, event, argv)
 
 
 def get_cid(event: MessageEvent):
@@ -102,14 +100,13 @@ def shortcut(cmd: str, argv: List[str] = [], **kwargs):
 
     @command.handle()
     async def _(
-        matcher: Matcher, event: GroupMessageEvent, msg: Message = CommandArg()
+        matcher: Matcher, event: MessageEvent, msg: Message = CommandArg()
     ):
         try:
             args = shlex.split(msg.extract_plain_text().strip())
         except:
             args = []
-        async with mutex:
-            await handle_wordle(matcher, event, argv + args)
+        await handle_wordle(matcher, event, argv + args)
 
 
 shortcut("猜单词", ["--length", "5", "--dic", "CET4"], rule=to_me())
@@ -121,10 +118,9 @@ word_matcher = on_message(Rule(game_running) & get_word_input, block=True, prior
 
 
 @word_matcher.handle()
-async def _(matcher: Matcher, event: GroupMessageEvent, state: T_State = State()):
+async def _(matcher: Matcher, event: MessageEvent, state: T_State = State()):
     word: str = state["word"]
-    async with mutex:
-        await handle_wordle(matcher, event, [word])
+    await handle_wordle(matcher, event, [word])
 
 
 async def stop_game(matcher: Matcher, cid: str):
@@ -148,7 +144,7 @@ def set_timeout(matcher: Matcher, cid: str, timeout: float = 300):
     timers[cid] = timer
 
 
-async def handle_wordle(matcher: Matcher, event: GroupMessageEvent, argv: List[str]):
+async def handle_wordle(matcher: Matcher, event: MessageEvent, argv: List[str]):
     async def send(
         message: Optional[str] = None, image: Optional[BytesIO] = None
     ) -> NoReturn:
